<?php

namespace Newage\Videos\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Newage\Videos\Interfaces\VideoRepositoryInterface;

class VideoPublicController extends BaseController
{
    // use VideoWorkflow;

    /**
     * Constructor.
     *
     * @param type \Newage\Video\Interfaces\VideoRepositoryInterface $video
     *
     * @return type
     */
    public function __construct(VideoRepositoryInterface $video)
    {
        $this->repository = $video;
        parent::__construct();
    }

    /**
     * Show video's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $videos = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$videos::$video.names'))
            ->view('$videos::public.video.index')
            ->data(compact('$videos'))
            ->output();
    }

    /**
     * Show video's list based on a type.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function list($type = null)
    {
        $videos = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->title(trans('$videos::$video.names'))
            ->view('$videos::public.video.index')
            ->data(compact('$videos'))
            ->output();
    }

    /**
     * Show video.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $video = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->title($$video->name . trans('$videos::$video.name'))
            ->view('$videos::public.video.show')
            ->data(compact('$video'))
            ->output();
    }

}
